#!/bin/sh -xv

# When you have a local cache of a wvs repository, you can use this script to
# check if the remote is accessible. There are 5 possible exit codes:
# 0 - Remote exists and is accessible
# 1 - The specified directory does not exist
# 2 - The specified directory is not a git repository
# 3 - No remote is configured for this repository
# 4 - Remote specified but does not exist or is not accessible

set +e

# Set REPO_DIR variable to the directory where your repository is located.
# It can be passed as an argument: REPO_DIR="$1"
REPO_DIR="$1"
REMOTE_TO_CHECK="$2"

if [ -d $REPO_DIR ]; then
    # Navigate to the repository directory
    cd "$REPO_DIR"

    # Check if it's a git repository
    if [ -d .git ] || git rev-parse --git-dir > /dev/null 2>&1; then
        # Check if an remote is configured
        git ls-remote $REMOTE_TO_CHECK &> /dev/null
        if [ $? -eq 0 ]; then
            # Try fetching from remote and check the exit status
            git fetch --force $REMOTE_TO_CHECK &> /dev/null
            if [ $? -eq 0 ]; then
                exit 0 # Remote exists and is accessible
            else
                exit 4 # Remote does not exist or is not accessible
            fi
        else
            exit 3 # No remote is configured for this repository
        fi
    else
        exit 2 # The specified directory is not a git repository
    fi
else
    exit 1 # The specified repo directory does not exist
fi
